Documentation
¶
Overview ¶
Package security provide basic data for security related information, such as user and roles and common http middleware for restricting request based on roles. Usually you do not need to install this package manually, security extensions should already have this package as their dependencies. Unless you're writing your own extension.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Authenticated ¶
Authenticated is http middleware which filter out unauthenticated incoming request. Notes: This handler doesn't works alone, you need to use other security component to handle authentication and save the user info into the sdk principal package, such as: security-oidc.
func RolesAllowed ¶
RolesAllowed is http middleware which filter incoming request based on speficied roles againts user roles. Notes: This handler doesn't works alone, you need to use other security component to handle authentication and save the user info into the sdk principal package, such as: security-oidc.
Types ¶
This section is empty.